--[[
	if hasRoP then
		local _, _, startTime, duration = GetTotemInfo(1)
		if startTime > 0 then
			wdw_Mage_timeLeftRoP = startTime+duration-GetTime()
		end
	end
--]]

-- Global reference
powerTalentTracker = {};
powerTalentTracker.spellName = nil;-- Set to currently talented spell name by detectTalent.
powerTalentTracker.buffName = nil;

-- Localized names.
local spellNames = {
	invocation = GetSpellInfo(114003),
	runeOfPower = GetSpellInfo(116011),
	incantersWard = GetSpellInfo(1463),

	invokersEnergy = GetSpellInfo(116257),	-- The buff Invocation gives us.
	runeOfPowerBuff = GetSpellInfo(116014),
	--incantersWardBuff = GetSpellInfo(118859),
}

function powerTalentTracker.init()
	powerTalentTracker.detectTalent();
end

-- Detect which bomb the player currently has.
-- Needs to be called if a player's talents change.
function powerTalentTracker.detectTalent()

	if (powerTalentTracker.hasSpell(spellNames.invocation)) then
		powerTalentTracker.spellName = spellNames.invocation;--SPELL_LIVING_BOMB_ID;
		powerTalentTracker.buffName = spellNames.invokersEnergy;

	elseif (powerTalentTracker.hasSpell(spellNames.runeOfPower)) then
		powerTalentTracker.spellName = spellNames.runeOfPower;
		powerTalentTracker.buffName = spellNames.runeOfPowerBuff;

	elseif (powerTalentTracker.hasSpell(spellNames.incantersWard)) then
		powerTalentTracker.spellName = spellNames.incantersWard;
		--powerTalentTracker.buffName = spellNames.incantersWardBuff;

	else
		powerTalentTracker.spellName = nil;
		powerTalentTracker.buffName = nil;
	end

end

function powerTalentTracker.hasSpell(spellId)
	local name = GetSpellInfo(spellId);
	local link = GetSpellLink(name);
	if (link ~= nil) then
		return true;
	else
		return false;
	end
end

function powerTalentTracker.getInfo()

	if (powerTalentTracker.spellName == nil) then	-- No target selected or no bomb talented.
		return nil, nil, nil, nil;
	end

	
	local cdTimeLeft = 0;

	-- Rune of Power
	if (powerTalentTracker.spellName == spellNames.runeOfPower) then

		buffName, _, _, _, _, duration, expirationTime = UnitBuff("PLAYER", spellNames.runeOfPowerBuff, nil, "PLAYER");
		if (buffName ~= nil) then

			-- Awful code to get the highest totem timer.
			local _, _, startTime1, duration1 = GetTotemInfo(1);
			local _, _, startTime2, duration2 = GetTotemInfo(2);
			if (startTime1 > 0 and startTime2 > 0) then

				if (startTime1 > startTime2) then
					local timeLeft = startTime1 + duration1 - GetTime();
					return duration1, timeLeft, powerTalentTracker.spellName, 0;
				else
					local timeLeft = startTime2 + duration2 - GetTime();
					return duration2, timeLeft, powerTalentTracker.spellName, 0;
				end
			elseif (startTime1 > 0) then
				local timeLeft = startTime1 + duration1 - GetTime();
				return duration1, timeLeft, powerTalentTracker.spellName, 0;
			elseif (startTime2 > 0) then
				local timeLeft = startTime2 + duration2 - GetTime();
				return duration2, timeLeft, powerTalentTracker.spellName, 0;
			end

		end


	-- Incanter's Ward
	elseif (powerTalentTracker.spellName == spellNames.incantersWard) then

		local cdStart, cdDuration, enabled = GetSpellCooldown(spellNames.incantersWard);
		if (cdDuration > 10 and cdStart > 0) then
			duration = cdDuration;
			timeLeft = duration - (GetTime() - cdStart);
			return duration, timeLeft, powerTalentTracker.spellName, cdTimeLeft;
		end

	-- Invocation
	else
		duration, timeLeft = powerTalentTracker.getBuffTimeLeft(powerTalentTracker.buffName);
		return duration, timeLeft, powerTalentTracker.spellName, cdTimeLeft;
	end

	return nil, nil, nil, nil;

end

-- UnitDebuff does not work unless we use the name. Otherwise we have to loop through all spells.
function powerTalentTracker.getBuffTimeLeft(spellName)
	buffName, _, _, _, _, duration, timeLeft = UnitBuff("PLAYER", spellName, nil, "PLAYER");
	if (buffName ~= nil) then
		return duration, timeLeft - GetTime();
	else
		return nil, nil
	end
end